# Generated by roxygen2: do not edit by hand

export(MapTaxaObs)
export(assign_IndexClass)
export(markExcluded)
export(metric.scores)
export(metric.stats)
export(metric.stats2)
export(metric.values)
export(metric.values.algae)
export(metric.values.bugs)
export(metric.values.coral)
export(metric.values.fish)
export(metvalgrpxl)
export(qc.checks)
export(qc_taxa)
export(qc_taxa_match_official)
export(qc_taxa_names_proof)
export(qc_taxa_phylo)
export(qc_taxa_values_character)
export(qc_taxa_values_logical)
export(qc_taxa_values_numeric)
export(rarify)
export(taxa_translate)
importFrom(rlang,.data)
