# MapTaxaObs ####
test_that("MapTaxaObs", {

  # df_obs <- data_Taxa_MA
  # SampID <- "estuary"
  # TaxaID <- "TaxaName"
  # TaxaCount <- "Count"
  # Lat <- "Latitude"
  # Long <- "Longitude"
  # output_dir <- getwd()
  # output_prefix <- "maps.taxa."
  # output_type <- "pdf"
  #
  # myDB <- "state"
  # myRegion <- "massachusetts"
  # myXlim     <- c(-(73+(30/60)), -(69+(56/60)))
  # myYlim     <- c((41+(14/60)),(42+(53/60)))
  #
  # # Run function with extra arguments for map
  # ## Not run:
  # MapTaxaObs(df_obs
  #            , SampID
  #            , TaxaID
  #            , TaxaCount
  #            , Lat
  #            , Long
  #            , database="state"
  #            , regions="massachusetts"
  #            , xlim=myXlim
  #            , ylim=myYlim)
  #
  # ## End(Not run)

})## Test ~ MapTaxaObs ~ END

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
