# Test for Index_Name and Index_Class between files
#
# Bugs ----
## IndexClass, bugs----
# testthat::test_that("IndexClass, xlNames", {
#
#   # Files
#   fn_MetricFlags <- file.path(system.file(package="BioMonTools")
#                               , "extdata"
#                               , "MetricFlags.xlsx")
#   fn_MetricScoring <- file.path(system.file(package="BioMonTools")
#                                 , "extdata"
#                                 , "MetricScoring.xlsx")
#   fn_IndexClass <- file.path(system.file(package="BioMonTools")
#                              , "extdata"
#                              , "IndexClass")
#
#   # Import
#   df_MetricFlags   <- as.data.frame(readxl::read_excel(fn_MetricFlags
#                                                       , sheet="Flags"))
#   df_MetricScoring   <- as.data.frame(readxl::read_excel(fn_MetricFlags
#                                                        , sheet="Flags"))
#
#   df_IndexClass   <- as.data.frame(readxl::read_excel(fn_MetricFlags
#                                                          , sheet="Flags"))
#
#   # Still work to do
#
# })## test ~ IndexClass, xlNames

# Fish ----

# Algae ----

